@@ -24,7 +24,7 @@ do_ttest <- function(mx, mu, stder, alt, df, conf) {
   inds <- alt=="two.sided"
   if(any(inds)) {
     res[inds,2] <- 2 * stats::pt(-abs(res[inds,1]), df[inds])
-    intrange    <- stats::qt(1 - (1-conf[inds])/2, df[inds])
+    intrange    <- stats::qt(1 - (1-conf[inds])*0.5, df[inds])
     res[inds,3] <- res[inds,1] - intrange
     res[inds,4] <- res[inds,1] + intrange
   }
@@ -34,10 +34,47 @@ do_ttest <- function(mx, mu, stder, alt, df, conf) {
   res
 }
 
+# Obtain p-values and confidence intervals for f-tests
+do_ftest <- function(est, rat, alt, df1, df2, conf) {
+  res <- matrix(numeric(), nrow=length(est), ncol=4)
+  colnames(res) <- c("f", "p", "cl", "ch")
+
+  df1[df1 <= 0] <- NA
+  df2[df2 <= 0] <- NA
+
+  res[,1] <- est/rat
+
+  inds <- alt=="less"
+  if(any(inds)) {
+    res[inds,2] <- stats::pf(res[inds,1], df1[inds], df2[inds])
+    res[inds,3] <- 0
+    res[inds,4] <- est[inds] / stats::qf(1 - conf[inds], df1[inds], df2[inds])
+  }
+
+  inds <- alt=="greater"
+  if(any(inds)) {
+    res[inds,2] <- 1 - stats::pf(res[inds,1], df1[inds], df2[inds])
+    res[inds,3] <- est[inds] / stats::qf(conf[inds], df1[inds], df2[inds])
+    res[inds,4] <- Inf
+  }
+
+  inds <- alt=="two.sided"
+  if(any(inds)) {
+    pval <- stats::pf(res[inds,1], df1[inds], df2[inds])
+    beta <- (1 - conf[inds]) * 0.5
+    res[inds,2] <- 2 * pmin(pval, 1 - pval)
+    res[inds,3] <- est[inds] / stats::qf(1-beta, df1[inds], df2[inds])
+    res[inds,4] <- est[inds] / stats::qf(beta, df1[inds], df2[inds])
+  }
+
+  res
+}
+
+
 do_wilcox_1_exact <- function(stat, n, alt) {
   res <- rep(NA_integer_, length(stat))
 
-  case <- stat > (n * (n+1)/4)
+  case <- stat > (n * (n+1)*0.25)
 
 
   inds <- alt=="two.sided" & case
@@ -68,7 +105,7 @@ do_wilcox_1_exact <- function(stat, n, alt) {
 do_wilcox_1_approx <- function(stat, n, alt, nties, correct) {
   res <- rep(NA_integer_, length(stat))
 
-  z <- stat - n * (n+1)/4
+  z <- stat - n * (n+1)*0.25
   correction <- rep(0, length(stat))
   correction[correct & alt=="two.sided"] <- sign(z[correct & alt=="two.sided"]) * 0.5
   correction[correct & alt=="greater"]   <- 0.5
@@ -100,7 +137,7 @@ do_wilcox_1_approx <- function(stat, n, alt, nties, correct) {
 do_wilcox_2_exact <- function(stat, nx, ny, alt) {
   res <- rep(NA_integer_, length(stat))
 
-  case <- stat > (nx*ny/2)
+  case <- stat > (nx*ny*0.5)
 
 
   inds <- alt=="two.sided" & case
@@ -131,7 +168,7 @@ do_wilcox_2_exact <- function(stat, nx, ny, alt) {
 do_wilcox_2_approx <- function(stat, nx, ny, alt, nties, correct) {
   res <- rep(NA_integer_, length(stat))
 
-  z <- stat - nx*ny/2
+  z <- stat - nx*ny*0.5
   correction <- rep(0, length(stat))
   correction[correct & alt=="two.sided"] <- sign(z[correct & alt=="two.sided"]) * 0.5
   correction[correct & alt=="greater"]   <- 0.5
@@ -167,7 +204,7 @@ do_pearson <- function(r, df, alt, conf) {
 
   df[df<=0] <- NA
 
-  res[,1] <- sqrt(df)*r / sqrt(1 - r^2)
+  res[,1] <- sqrt(df)*r / sqrt(1 - r*r)
   z <- atanh(r)
   sigma <- 1/sqrt(df-1)
 
@@ -188,8 +225,8 @@ do_pearson <- function(r, df, alt, conf) {
   inds <- alt=="two.sided"
   if(any(inds)) {
     res[inds,2] <- 2 * pmin(stats::pt(res[inds,1], df[inds]), stats::pt(res[inds,1], df[inds], lower.tail=FALSE))
-    res[inds,3] <- z[inds] + -sigma[inds] * stats::qnorm((1 + conf[inds])/2)
-    res[inds,4] <- z[inds] + sigma[inds] * stats::qnorm((1 + conf[inds])/2)
+    res[inds,3] <- z[inds] + -sigma[inds] * stats::qnorm((1 + conf[inds])*0.5)
+    res[inds,4] <- z[inds] + sigma[inds] * stats::qnorm((1 + conf[inds])*0.5)
   }
 
   res[,3] <- tanh(res[,3])
