@@ -20,6 +20,8 @@ test_that("row eq col on matrix xs and ys", {
   expect_equal(row_kruskalwallis(X, g), col_kruskalwallis(t(X), g))
   expect_equal(row_bartlett(X, g), col_bartlett(t(X), g))
   expect_equal(row_flignerkilleen(X, g), col_flignerkilleen(t(X), g))
+  expect_equal(row_levene(X, g), col_levene(t(X), g))
+  expect_equal(row_brownforsythe(X, g), col_brownforsythe(t(X), g))
   expect_equal(row_cor_pearson(X, Y), col_cor_pearson(t(X), t(Y)))
   expect_equal(row_jarquebera(X), col_jarquebera(t(X)))
   expect_equal(row_wilcoxon_onesample(X), col_wilcoxon_onesample(t(X)))
@@ -44,6 +46,8 @@ test_that("row eq col on data.frame xs and ys", {
   expect_equal(row_kruskalwallis(X, g), col_kruskalwallis(t(X), g))
   expect_equal(row_bartlett(X, g), col_bartlett(t(X), g))
   expect_equal(row_flignerkilleen(X, g), col_flignerkilleen(t(X), g))
+  expect_equal(row_levene(X, g), col_levene(t(X), g))
+  expect_equal(row_brownforsythe(X, g), col_brownforsythe(t(X), g))
   expect_equal(row_cor_pearson(X, Y), col_cor_pearson(t(X), t(Y)))
   expect_equal(row_jarquebera(X), col_jarquebera(t(X)))
   expect_equal(row_wilcoxon_onesample(X), col_wilcoxon_onesample(t(X)))
@@ -68,6 +72,8 @@ test_that("row eq col on vector xs and ys", {
   expect_equal(row_kruskalwallis(X, g), col_kruskalwallis(X, g))
   expect_equal(row_bartlett(X, g), col_bartlett(X, g))
   expect_equal(row_flignerkilleen(X, g), col_flignerkilleen(X, g))
+  expect_equal(row_levene(X, g), col_levene(X, g))
+  expect_equal(row_brownforsythe(X, g), col_brownforsythe(X, g))
   expect_equal(row_cor_pearson(X, Y), col_cor_pearson(X, Y))
   expect_equal(row_jarquebera(X), col_jarquebera(X))
   expect_equal(row_wilcoxon_onesample(X), col_wilcoxon_onesample(X))
@@ -92,6 +98,8 @@ test_that("row eq col on 0 dimension matrix xs and ys", {
   expect_equal(row_kruskalwallis(X, g), col_kruskalwallis(X, g))
   expect_equal(row_bartlett(X, g), col_bartlett(X, g))
   expect_equal(row_flignerkilleen(X, g), col_flignerkilleen(X, g))
+  expect_equal(row_levene(X, g), col_levene(X, g))
+  expect_equal(row_brownforsythe(X, g), col_brownforsythe(X, g))
   expect_equal(row_cor_pearson(X, Y), col_cor_pearson(X, Y))
   expect_equal(row_jarquebera(X), col_jarquebera(X))
   expect_equal(row_wilcoxon_onesample(X), col_wilcoxon_onesample(X))
