@@ -21,6 +21,8 @@ test_that("x and y can be numeric vectors", {
   expect_equal(row_ievora(x=x, b=grp), row_ievora(x=X, b=grp))
   expect_equal(row_jarquebera(x=x), row_jarquebera(x=X))
   expect_equal(row_flignerkilleen(x=x, g=grp), row_flignerkilleen(x=X, g=grp))
+  expect_equal(row_levene(x=x, g=grp), row_levene(x=X, g=grp))
+  expect_equal(row_brownforsythe(x=x, g=grp), row_brownforsythe(x=X, g=grp))
   expect_equal(row_wilcoxon_onesample(x=x), row_wilcoxon_onesample(x=X))
   expect_equal(row_wilcoxon_twosample(x=x, y=y), row_wilcoxon_twosample(x=X, y=Y))
   expect_equal(row_wilcoxon_paired(x=x, y=y), row_wilcoxon_paired(x=X, y=Y))
@@ -43,6 +45,8 @@ test_that("x and y can be numeric data.frames", {
   expect_equal(row_ievora(x=x, b=grp), row_ievora(x=X, b=grp))
   expect_equal(row_jarquebera(x=x), row_jarquebera(x=X))
   expect_equal(row_flignerkilleen(x=x, g=grp), row_flignerkilleen(x=X, g=grp))
+  expect_equal(row_levene(x=x, g=grp), row_levene(x=X, g=grp))
+  expect_equal(row_brownforsythe(x=x, g=grp), row_brownforsythe(x=X, g=grp))
   expect_equal(row_wilcoxon_onesample(x=x), row_wilcoxon_onesample(x=X))
   expect_equal(row_wilcoxon_twosample(x=x, y=y), row_wilcoxon_twosample(x=X, y=Y))
   expect_equal(row_wilcoxon_paired(x=x, y=y), row_wilcoxon_paired(x=X, y=Y))
@@ -65,6 +69,8 @@ test_that("x and y can have 0 rows and 0 columns", {
   expect_equal(nrow(row_ievora(x=x, b=grp)), 0)
   expect_equal(nrow(row_jarquebera(x=x)), 0)
   expect_equal(nrow(row_flignerkilleen(x=x, g=grp)), 0)
+  expect_equal(nrow(row_levene(x=x, g=grp)), 0)
+  expect_equal(nrow(row_brownforsythe(x=x, g=grp)), 0)
   expect_equal(nrow(row_wilcoxon_onesample(x=x)), 0)
   expect_equal(nrow(row_wilcoxon_twosample(x=x, y=y)), 0)
   expect_equal(nrow(row_wilcoxon_paired(x=x, y=y)), 0)
@@ -92,6 +98,8 @@ test_that("NA and NaN are treated the same", {
   expect_equal(row_ievora(x=Xna, b=grp), row_ievora(x=Xnan, b=grp))
   expect_equal(row_jarquebera(x=Xna), row_jarquebera(x=Xnan))
   expect_equal(row_flignerkilleen(x=Xna, g=grp), row_flignerkilleen(x=Xnan, g=grp))
+  expect_equal(row_levene(x=Xna, g=grp), row_levene(x=Xnan, g=grp))
+  expect_equal(row_brownforsythe(x=Xna, g=grp), row_brownforsythe(x=Xnan, g=grp))
   expect_equal(row_wilcoxon_onesample(x=Xna), row_wilcoxon_onesample(x=Xnan))
   expect_equal(row_wilcoxon_twosample(x=Xna, y=Yna), row_wilcoxon_twosample(x=Xnan, y=Ynan))
   expect_equal(row_wilcoxon_paired(x=Xna, y=Yna), row_wilcoxon_paired(x=Xnan, y=Ynan))
@@ -138,6 +146,10 @@ test_that("NA and NaN produce the same result", {
   expect_equal(suppressWarnings(row_ievora(x=x, b=grp1)), suppressWarnings(row_ievora(x=x, b=grp3)))
   expect_equal(suppressWarnings(row_flignerkilleen(x=x, g=grp1)), suppressWarnings(row_flignerkilleen(x=x, g=grp2)))
   expect_equal(suppressWarnings(row_flignerkilleen(x=x, g=grp1)), suppressWarnings(row_flignerkilleen(x=x, g=grp3)))
+  expect_equal(suppressWarnings(row_levene(x=x, g=grp1)), suppressWarnings(row_levene(x=x, g=grp2)))
+  expect_equal(suppressWarnings(row_levene(x=x, g=grp1)), suppressWarnings(row_levene(x=x, g=grp2)))
+  expect_equal(suppressWarnings(row_brownforsythe(x=x, g=grp1)), suppressWarnings(row_brownforsythe(x=x, g=grp3)))
+  expect_equal(suppressWarnings(row_brownforsythe(x=x, g=grp1)), suppressWarnings(row_brownforsythe(x=x, g=grp3)))
 })
 
 test_that("groups can all be NA", {
@@ -149,6 +161,8 @@ test_that("groups can all be NA", {
   expect_equal(suppressWarnings(row_bartlett(x=x, g=grp)$obs.tot), rep(0, nrow(x)))
   expect_equal(suppressWarnings(row_ievora(x=x, b=grp)$obs.0), rep(0, nrow(x)))
   expect_equal(suppressWarnings(row_flignerkilleen(x=x, g=grp)$obs.tot), rep(0, nrow(x)))
+  expect_equal(suppressWarnings(row_levene(x=x, g=grp)$obs.tot), rep(0, nrow(x)))
+  expect_equal(suppressWarnings(row_brownforsythe(x=x, g=grp)$obs.tot), rep(0, nrow(x)))
 })
 
 test_that("groups can all be NaN", {
@@ -160,6 +174,8 @@ test_that("groups can all be NaN", {
   expect_equal(suppressWarnings(row_bartlett(x=x, g=grp)$obs.tot), rep(0, nrow(x)))
   expect_equal(suppressWarnings(row_ievora(x=x, b=grp)$obs.0), rep(0, nrow(x)))
   expect_equal(suppressWarnings(row_flignerkilleen(x=x, g=grp)$obs.tot), rep(0, nrow(x)))
+  expect_equal(suppressWarnings(row_levene(x=x, g=grp)$obs.tot), rep(0, nrow(x)))
+  expect_equal(suppressWarnings(row_brownforsythe(x=x, g=grp)$obs.tot), rep(0, nrow(x)))
 })
 
 test_that("all observations can be in the same group", {
@@ -171,6 +187,8 @@ test_that("all observations can be in the same group", {
   expect_equal(suppressWarnings(row_bartlett(x=x, g=grp)$obs.groups), rep(1, nrow(x)))
   expect_equal(suppressWarnings(row_ievora(x=x, b=grp)$obs.0), rep(ncol(x), nrow(x)))
   expect_equal(suppressWarnings(row_flignerkilleen(x=x, g=grp)$obs.groups), rep(1, nrow(x)))
+  expect_equal(suppressWarnings(row_levene(x=x, g=grp)$obs.groups), rep(1, nrow(x)))
+  expect_equal(suppressWarnings(row_brownforsythe(x=x, g=grp)$obs.groups), rep(1, nrow(x)))
 })
 
 test_that("groups can be character", {
@@ -183,6 +201,8 @@ test_that("groups can be character", {
   expect_equal(row_bartlett(x=x, g=grp1), row_bartlett(x=x, g=grp2))
   expect_equal(row_ievora(x=x, b=grp1), row_ievora(x=x, b=grp2))
   expect_equal(row_flignerkilleen(x=x, g=grp1), row_flignerkilleen(x=x, g=grp2))
+  expect_equal(row_levene(x=x, g=grp1), row_levene(x=x, g=grp2))
+  expect_equal(row_brownforsythe(x=x, g=grp1), row_brownforsythe(x=x, g=grp2))
 })
 
 test_that("groups can be factor", {
@@ -195,6 +215,8 @@ test_that("groups can be factor", {
   expect_equal(row_bartlett(x=x, g=grp1), row_bartlett(x=x, g=grp2))
   expect_equal(row_ievora(x=x, b=grp1), row_ievora(x=x, b=grp2))
   expect_equal(row_flignerkilleen(x=x, g=grp1), row_flignerkilleen(x=x, g=grp2))
+  expect_equal(row_levene(x=x, g=grp1), row_levene(x=x, g=grp2))
+  expect_equal(row_brownforsythe(x=x, g=grp1), row_brownforsythe(x=x, g=grp2))
 })
 
 test_that("groups can be logical", {
@@ -207,6 +229,8 @@ test_that("groups can be logical", {
   expect_equal(row_bartlett(x=x, g=grp1), row_bartlett(x=x, g=grp2))
   expect_equal(row_ievora(x=x, b=grp1), row_ievora(x=x, b=grp2))
   expect_equal(row_flignerkilleen(x=x, g=grp1), row_flignerkilleen(x=x, g=grp2))
+  expect_equal(row_levene(x=x, g=grp1), row_levene(x=x, g=grp2))
+  expect_equal(row_brownforsythe(x=x, g=grp1), row_brownforsythe(x=x, g=grp2))
 })
 
 test_that("groups can be complex", {
@@ -219,6 +243,8 @@ test_that("groups can be complex", {
   expect_equal(row_bartlett(x=x, g=grp1), row_bartlett(x=x, g=grp2))
   expect_equal(row_ievora(x=x, b=grp1), row_ievora(x=x, b=grp2))
   expect_equal(row_flignerkilleen(x=x, g=grp1), row_flignerkilleen(x=x, g=grp2))
+  expect_equal(row_levene(x=x, g=grp1), row_levene(x=x, g=grp2))
+  expect_equal(row_brownforsythe(x=x, g=grp1), row_brownforsythe(x=x, g=grp2))
 })
 
 test_that("groups can be a list", {
@@ -231,6 +257,8 @@ test_that("groups can be a list", {
   expect_equal(row_bartlett(x=x, g=grp1), row_bartlett(x=x, g=grp2))
   expect_equal(row_ievora(x=x, b=grp1), row_ievora(x=x, b=grp2))
   expect_equal(row_flignerkilleen(x=x, g=grp1), row_flignerkilleen(x=x, g=grp2))
+  expect_equal(row_levene(x=x, g=grp1), row_levene(x=x, g=grp2))
+  expect_equal(row_brownforsythe(x=x, g=grp1), row_brownforsythe(x=x, g=grp2))
 })
 
 test_that("groups can be a matrix", {
@@ -243,6 +271,8 @@ test_that("groups can be a matrix", {
   expect_equal(row_bartlett(x=x, g=grp1), row_bartlett(x=x, g=grp2))
   expect_equal(row_ievora(x=x, b=grp1), row_ievora(x=x, b=grp2))
   expect_equal(row_flignerkilleen(x=x, g=grp1), row_flignerkilleen(x=x, g=grp2))
+  expect_equal(row_levene(x=x, g=grp1), row_levene(x=x, g=grp2))
+  expect_equal(row_brownforsythe(x=x, g=grp1), row_brownforsythe(x=x, g=grp2))
 })
 
 test_that("groups can be infinite", {
@@ -255,6 +285,8 @@ test_that("groups can be infinite", {
   expect_equal(row_bartlett(x=x, g=grp1), row_bartlett(x=x, g=grp2))
   expect_equal(row_ievora(x=x, b=grp1), row_ievora(x=x, b=grp2))
   expect_equal(row_flignerkilleen(x=x, g=grp1), row_flignerkilleen(x=x, g=grp2))
+  expect_equal(row_levene(x=x, g=grp1), row_levene(x=x, g=grp2))
+  expect_equal(row_brownforsythe(x=x, g=grp1), row_brownforsythe(x=x, g=grp2))
 })
 
 ################################################################################
