@@ -17,6 +17,8 @@ test_that("when no row-names in the input - numbers are added", {
   expect_equal(rownames(row_ievora(x=X, b=grp)), rnames)
   expect_equal(rownames(row_jarquebera(x=X)), rnames)
   expect_equal(rownames(row_flignerkilleen(x=X, g=grp)), rnames)
+  expect_equal(rownames(row_levene(x=X, g=grp)), rnames)
+  expect_equal(rownames(row_brownforsythe(x=X, g=grp)), rnames)
   expect_equal(rownames(row_wilcoxon_onesample(x=X)), rnames)
   expect_equal(rownames(row_wilcoxon_twosample(x=X, y=Y)), rnames)
   expect_equal(rownames(row_wilcoxon_paired(x=X, y=Y)), rnames)
@@ -42,6 +44,8 @@ test_that("when X doesn't have rownames - names from Y or groups are not used",
   expect_equal(rownames(row_ievora(x=X, b=grp)), rnames)
   expect_equal(rownames(row_jarquebera(x=X)), rnames)
   expect_equal(rownames(row_flignerkilleen(x=X, g=grp)), rnames)
+  expect_equal(rownames(row_levene(x=X, g=grp)), rnames)
+  expect_equal(rownames(row_brownforsythe(x=X, g=grp)), rnames)
   expect_equal(rownames(row_wilcoxon_onesample(x=X)), rnames)
   expect_equal(rownames(row_wilcoxon_twosample(x=X, y=Y)), rnames)
   expect_equal(rownames(row_wilcoxon_paired(x=X, y=Y)), rnames)
@@ -67,6 +71,8 @@ test_that("when row-names are specified - they are preserved", {
   expect_equal(rownames(row_ievora(x=X, b=grp)), rnames)
   expect_equal(rownames(row_jarquebera(x=X)), rnames)
   expect_equal(rownames(row_flignerkilleen(x=X, g=grp)), rnames)
+  expect_equal(rownames(row_levene(x=X, g=grp)), rnames)
+  expect_equal(rownames(row_brownforsythe(x=X, g=grp)), rnames)
   expect_equal(rownames(row_wilcoxon_onesample(x=X)), rnames)
   expect_equal(rownames(row_wilcoxon_twosample(x=X, y=Y)), rnames)
   expect_equal(rownames(row_wilcoxon_paired(x=X, y=Y)), rnames)
@@ -86,6 +92,8 @@ test_that("when row-names are specified - they are preserved", {
   expect_equal(rownames(row_ievora(x=X, b=grp)), rnames)
   expect_equal(rownames(row_jarquebera(x=X)), rnames)
   expect_equal(rownames(row_flignerkilleen(x=X, g=grp)), rnames)
+  expect_equal(rownames(row_levene(x=X, g=grp)), rnames)
+  expect_equal(rownames(row_brownforsythe(x=X, g=grp)), rnames)
   expect_equal(rownames(row_wilcoxon_onesample(x=X)), rnames)
   expect_equal(rownames(row_wilcoxon_twosample(x=X, y=Y)), rnames)
   expect_equal(rownames(row_wilcoxon_paired(x=X, y=Y)), rnames)
@@ -110,6 +118,8 @@ test_that("when row-names are duplicated - they are modified to be unique", {
   expect_equal(rownames(row_ievora(x=X, b=grp)), rnames)
   expect_equal(rownames(row_jarquebera(x=X)), rnames)
   expect_equal(rownames(row_flignerkilleen(x=X, g=grp)), rnames)
+  expect_equal(rownames(row_levene(x=X, g=grp)), rnames)
+  expect_equal(rownames(row_brownforsythe(x=X, g=grp)), rnames)
   expect_equal(rownames(row_wilcoxon_onesample(x=X)), rnames)
   expect_equal(rownames(row_wilcoxon_twosample(x=X, y=Y)), rnames)
   expect_equal(rownames(row_wilcoxon_paired(x=X, y=Y)), rnames)
